A list filled with estimated Markov neighborhood for each graph vertex
Arguments
a_size
Size of the alphabet.
sample
A integer-valued matrix. Each value must belong range 0
and a_size - 1. Matrix has dimension n x V, where
n is number of samples and V is number of nodes.
tau
A hyperparameter. See references.
max_degree
The maximum length of a candidate Markovian neighborhood. Must be
non-negative and less than ncol(sample).
Author
Rodrigo Carvalho
References
Guy Bresler. 2015. Efficiently Learning Ising Models on Arbitrary Graphs. In Proceedings of the forty-seventh annual ACM symposium on Theory of Computing (STOC '15). Association for Computing Machinery, New York, NY, USA, 771–782. DOI:https://doi.org/10.1145/2746539.2746631